==> openshift-model-miscellaneous-6.7.2-sources.jar: io/fabric8/openshift/api/model/miscellaneous/apiserver/v1/APIRequestCountListBuilder.java <==
package io.fabric8.openshift.api.model.miscellaneous.apiserver.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class APIRequestCountListBuilder extends APIRequestCountListFluentImpl<APIRequestCountListBuilder> implements VisitableBuilder<APIRequestCountList,APIRequestCountListBuilder>{
  public APIRequestCountListBuilder() {
    this(false);
  }
  public APIRequestCountListBuilder(Boolean validationEnabled) {
    this(new APIRequestCountList(), validationEnabled);
  }
  public APIRequestCountListBuilder(APIRequestCountListFluent<?> fluent) {
    this(fluent, false);
  }
  public APIRequestCountListBuilder(APIRequestCountListFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new APIRequestCountList(), validationEnabled);
  }
  public APIRequestCountListBuilder(APIRequestCountListFluent<?> fluent,APIRequestCountList instance) {
    this(fluent, instance, false);
  }
  public APIRequestCountListBuilder(APIRequestCountListFluent<?> fluent,APIRequestCountList instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withItems(instance.getItems());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public APIRequestCountListBuilder(APIRequestCountList instance) {
    this(instance,false);
  }
  public APIRequestCountListBuilder(APIRequestCountList instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withItems(instance.getItems());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  APIRequestCountListFluent<?> fluent;
  Boolean validationEnabled;
  public APIRequestCountList build() {
    APIRequestCountList buildable = new APIRequestCountList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> openshift-model-miscellaneous-6.8.0-sources.jar: io/fabric8/openshift/api/model/miscellaneous/apiserver/v1/APIRequestCountListBuilder.java <==
package io.fabric8.openshift.api.model.miscellaneous.apiserver.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class APIRequestCountListBuilder extends APIRequestCountListFluent<APIRequestCountListBuilder> implements VisitableBuilder<APIRequestCountList,APIRequestCountListBuilder>{
  public APIRequestCountListBuilder() {
    this(false);
  }
  public APIRequestCountListBuilder(Boolean validationEnabled) {
    this(new APIRequestCountList(), validationEnabled);
  }
  public APIRequestCountListBuilder(APIRequestCountListFluent<?> fluent) {
    this(fluent, false);
  }
  public APIRequestCountListBuilder(APIRequestCountListFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new APIRequestCountList(), validationEnabled);
  }
  public APIRequestCountListBuilder(APIRequestCountListFluent<?> fluent,APIRequestCountList instance) {
    this(fluent, instance, false);
  }
  public APIRequestCountListBuilder(APIRequestCountListFluent<?> fluent,APIRequestCountList instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new APIRequestCountList());

    if (instance != null) {
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withItems(instance.getItems());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withItems(instance.getItems());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public APIRequestCountListBuilder(APIRequestCountList instance) {
    this(instance,false);
  }
  public APIRequestCountListBuilder(APIRequestCountList instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new APIRequestCountList());

    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withItems(instance.getItems());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withApiVersion(instance.getApiVersion());
      this.withItems(instance.getItems());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  APIRequestCountListFluent<?> fluent;
  Boolean validationEnabled;
  public APIRequestCountList build() {
    APIRequestCountList buildable = new APIRequestCountList(fluent.getApiVersion(),fluent.buildItems(),fluent.getKind(),fluent.getMetadata());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
